<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko_KR">
<context>
    <name>GuidelineEditDialog</name>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="14"/>
        <source>Edit guideline...</source>
        <translation>안내선 수정...</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="22"/>
        <source>Page:</source>
        <translation>페이지:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="36"/>
        <source>Position:</source>
        <translation>위치:</translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="53"/>
        <source>cm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="58"/>
        <source>in</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/GuidelineEditDialog.ui" line="63"/>
        <source>bp</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PaperSize</name>
    <message>
        <location filename="../src/PaperSizes.cpp" line="24"/>
        <source>Beamer 16:10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="25"/>
        <source>Beamer 16:9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="26"/>
        <source>Beamer 14:9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="27"/>
        <source>Beamer 1.41:1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="28"/>
        <source>Beamer 5:4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="29"/>
        <source>Beamer 4:3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="30"/>
        <source>Beamer 3:2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="33"/>
        <source>Screen</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="36"/>
        <source>DIN 4A0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="37"/>
        <source>DIN 2A0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="38"/>
        <source>DIN A0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="39"/>
        <source>DIN A1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="40"/>
        <source>DIN A2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="41"/>
        <source>DIN A3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="42"/>
        <source>DIN A4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="43"/>
        <source>DIN A5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="44"/>
        <source>DIN A6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="45"/>
        <source>DIN A7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="46"/>
        <source>DIN A8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="47"/>
        <source>DIN A9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="48"/>
        <source>DIN A10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="49"/>
        <source>DIN B0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="50"/>
        <source>DIN B1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="51"/>
        <source>DIN B2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="52"/>
        <source>DIN B3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="53"/>
        <source>DIN B4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="54"/>
        <source>DIN B5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="55"/>
        <source>DIN B6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="56"/>
        <source>DIN B7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="57"/>
        <source>DIN B8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="58"/>
        <source>DIN B9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="59"/>
        <source>DIN B10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="60"/>
        <source>DIN C0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="61"/>
        <source>DIN C1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="62"/>
        <source>DIN C2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="63"/>
        <source>DIN C3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="64"/>
        <source>DIN C4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="65"/>
        <source>DIN C5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="66"/>
        <source>DIN C6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="67"/>
        <source>DIN C7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="68"/>
        <source>DIN C8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="69"/>
        <source>DIN C9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="70"/>
        <source>DIN C10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="71"/>
        <source>DIN DL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="72"/>
        <source>DIN DLE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="73"/>
        <source>DIN C6/C5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="74"/>
        <source>DIN RA0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="75"/>
        <source>DIN RA1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="76"/>
        <source>DIN RA2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="77"/>
        <source>DIN RA3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="78"/>
        <source>DIN RA4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="79"/>
        <source>DIN SRA0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="80"/>
        <source>DIN SRA1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="81"/>
        <source>DIN SRA2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="82"/>
        <source>DIN SRA3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="83"/>
        <source>DIN SRA4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="84"/>
        <source>SIS D0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="85"/>
        <source>SIS D1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="86"/>
        <source>SIS D2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="87"/>
        <source>SIS D3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="88"/>
        <source>SIS D4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="89"/>
        <source>SIS D5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="90"/>
        <source>SIS D6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="91"/>
        <source>SIS D7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="92"/>
        <source>SIS D8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="93"/>
        <source>SIS D9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="94"/>
        <source>SIS E0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="95"/>
        <source>SIS E1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="96"/>
        <source>SIS E2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="97"/>
        <source>SIS E3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="98"/>
        <source>SIS E4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="99"/>
        <source>SIS E5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="100"/>
        <source>SIS E6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="101"/>
        <source>SIS E7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="102"/>
        <source>SIS E8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="103"/>
        <source>SIS E9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="104"/>
        <source>SIS F0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="105"/>
        <source>SIS F1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="106"/>
        <source>SIS F2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="107"/>
        <source>SIS F3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="108"/>
        <source>SIS F4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="109"/>
        <source>SIS F5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="110"/>
        <source>SIS F6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="111"/>
        <source>SIS F7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="112"/>
        <source>SIS F8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="113"/>
        <source>SIS F9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="114"/>
        <source>SIS G0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="115"/>
        <source>SIS G1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="116"/>
        <source>SIS G2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="117"/>
        <source>SIS G3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="118"/>
        <source>SIS G4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="119"/>
        <source>SIS G5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="120"/>
        <source>SIS G6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="121"/>
        <source>SIS G7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="122"/>
        <source>SIS G8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="123"/>
        <source>SIS G9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="124"/>
        <source>JIS B0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="125"/>
        <source>JIS B1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="126"/>
        <source>JIS B2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="127"/>
        <source>JIS B3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="128"/>
        <source>JIS B4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="129"/>
        <source>JIS B5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="130"/>
        <source>JIS B6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="131"/>
        <source>JIS B7</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="132"/>
        <source>JIS B8</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="133"/>
        <source>JIS B9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="134"/>
        <source>JIS B10</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="135"/>
        <source>JIS B11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="136"/>
        <source>JIS B12</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="137"/>
        <source>JIS Shiroku ban 4</source>
        <translation>JIS 사륙판 4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="138"/>
        <source>JIS Shiroku ban 5</source>
        <translation>JIS 사륙판 5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="139"/>
        <source>JIS Shiroku ban 6</source>
        <translation>JIS 사륙판 6</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="140"/>
        <source>JIS Kiku 4</source>
        <translation>JIS 국판 4</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="141"/>
        <source>JIS Kiku 5</source>
        <translation>JIS 국판 5</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="142"/>
        <source>SAC D0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="143"/>
        <source>SAC D1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="144"/>
        <source>SAC D2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="145"/>
        <source>SAC D3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="146"/>
        <source>SAC D4</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="147"/>
        <source>SAC D5</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="148"/>
        <source>SAC D6</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="150"/>
        <source>Letter (ANSI A)</source>
        <translation>레터 (ANSI A)</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="151"/>
        <source>Legal</source>
        <translation>리걸</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="152"/>
        <source>Tabloid (ANSI B)</source>
        <translation>타블로이드 (ANSI B)</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="153"/>
        <source>Ledger</source>
        <translation>레저</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="154"/>
        <source>Junior Legal</source>
        <translation>주니어 리걸</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="155"/>
        <source>Half Letter</source>
        <translation>하프 레터</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="156"/>
        <source>Government Letter</source>
        <translation>거번먼트 레터</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="157"/>
        <source>Government Legal</source>
        <translation>거번먼트 리걸</translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="158"/>
        <source>ANSI C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="159"/>
        <source>ANSI D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="160"/>
        <source>ANSI E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="161"/>
        <source>Arch A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="162"/>
        <source>Arch B</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="163"/>
        <source>Arch C</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="164"/>
        <source>Arch D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="165"/>
        <source>Arch E1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="166"/>
        <source>Arch E</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="167"/>
        <source>Arch E2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="168"/>
        <source>Arch E3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="201"/>
        <source>mm</source>
        <extracomment>Length unit: millimeters</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PaperSizes.cpp" line="207"/>
        <source>in</source>
        <extracomment>Length unit: inches</extracomment>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtPDF</name>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="33"/>
        <source>[language name]</source>
        <translation>한국어</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="34"/>
        <source>[translator&apos;s name/email]</source>
        <translation>Dohyun Kim&amp;lt;nomosnomos@gmail.com&amp;gt;</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentScene</name>
    <message>
        <location filename="../src/PDFBackend.cpp" line="321"/>
        <source>rendering page</source>
        <translation>페이지 준비 중</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2013"/>
        <source>Unlock PDF</source>
        <translation>PDF 잠금 해제</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2013"/>
        <source>Please enter the password to unlock the PDF</source>
        <translation>PDF 잠금 해제를 위해 패스워드를 입력하세요</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
        <source>Incorrect password</source>
        <translation>패스워드 오류</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2029"/>
        <source>The password you entered was incorrect.</source>
        <translation>패스워드를 잘못 입력하셨습니다.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2035"/>
        <source>This document is locked. You need a password to open it.</source>
        <translation>문서가 잠겨 있습니다. 패스워드가 있어야 문서를 열 수 있습니다.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2036"/>
        <source>Unlock</source>
        <translation>잠금 해제</translation>
    </message>
</context>
<context>
    <name>QtPDF::PDFDocumentView</name>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="976"/>
        <source>Insufficient permission</source>
        <translation>권한 없음</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentTools.cpp" line="976"/>
        <source>Text extraction is not allowed for this document.</source>
        <translation>이 문서는 텍스트 추출이 허용되지 않습니다.</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2577"/>
        <source>Goto page %1</source>
        <translation>%1쪽으로 가기</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2589"/>
        <source>Execute `%1`</source>
        <translation>`%1` 실행</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2835"/>
        <location filename="../src/PDFDocumentView.cpp" line="2852"/>
        <source>Table of Contents</source>
        <translation>차례</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="2944"/>
        <location filename="../src/PDFDocumentView.cpp" line="3151"/>
        <source>Meta Data</source>
        <translation>메타 정보</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3000"/>
        <location filename="../src/PDFDocumentView.cpp" line="3161"/>
        <source>Processing</source>
        <translation>경과</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3032"/>
        <location filename="../src/PDFDocumentView.cpp" line="3168"/>
        <source>Other</source>
        <translation>기타</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3095"/>
        <source>Yes</source>
        <translation>예</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3098"/>
        <source>No</source>
        <translation>아니오</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3101"/>
        <location filename="../src/PDFDocumentView.cpp" line="3138"/>
        <source>Unknown</source>
        <translation>알 수 없음</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3153"/>
        <source>Document</source>
        <translation>문서</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3154"/>
        <source>Title:</source>
        <translation>제목:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3155"/>
        <source>Author:</source>
        <translation>작성자:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3156"/>
        <source>Subject:</source>
        <translation>주제:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3157"/>
        <source>Keywords:</source>
        <translation>키워드:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3162"/>
        <source>Creator:</source>
        <translation>작성 도구:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3163"/>
        <source>Producer:</source>
        <translation>제작 도구:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3164"/>
        <source>Creation date:</source>
        <translation>작성 날짜:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3165"/>
        <source>Modification date:</source>
        <translation>수정 날짜:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3166"/>
        <source>Trapped:</source>
        <translation>트랩됨:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3177"/>
        <location filename="../src/PDFDocumentView.cpp" line="3271"/>
        <source>Fonts</source>
        <translation>글꼴</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3227"/>
        <source>Type 0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3230"/>
        <source>Type 1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3233"/>
        <source>Type 1 (multiple master)</source>
        <translation>Type 1 (다중 마스터)</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3236"/>
        <source>Type 3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3239"/>
        <source>TrueType</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3242"/>
        <source>yes</source>
        <translation>예</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3242"/>
        <source>no</source>
        <translation>아니오</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3245"/>
        <source>[embedded]</source>
        <translation>[내장됨]</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3248"/>
        <source>[builtin]</source>
        <translation>[내장]</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
        <source>Type</source>
        <translation>유형</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
        <source>Subset</source>
        <translation>서브셋</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3272"/>
        <source>Source</source>
        <translation>위치</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3280"/>
        <location filename="../src/PDFDocumentView.cpp" line="3375"/>
        <source>Permissions</source>
        <translation>권한</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3329"/>
        <location filename="../src/PDFDocumentView.cpp" line="3338"/>
        <location filename="../src/PDFDocumentView.cpp" line="3347"/>
        <location filename="../src/PDFDocumentView.cpp" line="3354"/>
        <location filename="../src/PDFDocumentView.cpp" line="3359"/>
        <source>Allowed</source>
        <translation>허용됨</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3331"/>
        <source>Low resolution only</source>
        <translation>저해상도만 허용</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3334"/>
        <location filename="../src/PDFDocumentView.cpp" line="3344"/>
        <location filename="../src/PDFDocumentView.cpp" line="3351"/>
        <location filename="../src/PDFDocumentView.cpp" line="3356"/>
        <location filename="../src/PDFDocumentView.cpp" line="3361"/>
        <location filename="../src/PDFDocumentView.cpp" line="3366"/>
        <location filename="../src/PDFDocumentView.cpp" line="3367"/>
        <location filename="../src/PDFDocumentView.cpp" line="3368"/>
        <location filename="../src/PDFDocumentView.cpp" line="3369"/>
        <location filename="../src/PDFDocumentView.cpp" line="3370"/>
        <source>Denied</source>
        <translation>허용 안됨</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3340"/>
        <source>Assembling only</source>
        <translation>어셈블리만 허용</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3341"/>
        <source>Insert, rotate, or delete pages and create bookmarks or thumbnail images</source>
        <translation>페이지 삽입·회전·삭제 및 북마크·썸네일 넣기</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3349"/>
        <source>Accessibility support only</source>
        <translation>접근성 지원만 허용</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3377"/>
        <source>Printing:</source>
        <translation>인쇄:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3378"/>
        <source>Modifications:</source>
        <translation>내용 변경:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3379"/>
        <source>Extraction:</source>
        <translation>텍스트 추출:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3380"/>
        <source>Annotation:</source>
        <translation>주석 달기:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3381"/>
        <source>Filling forms:</source>
        <translation>양식 채우기:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3389"/>
        <location filename="../src/PDFDocumentView.cpp" line="3481"/>
        <source>Annotations</source>
        <translation>주석</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
        <source>Page</source>
        <translation>쪽</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
        <source>Subject</source>
        <translation>이름</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
        <source>Author</source>
        <translation>작성자</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3482"/>
        <source>Contents</source>
        <translation>내용</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3057"/>
        <source>B</source>
        <extracomment>File size: bytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3059"/>
        <source>kB</source>
        <extracomment>File size: kilobytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3061"/>
        <source>MB</source>
        <extracomment>File size: megabytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3063"/>
        <source>GB</source>
        <extracomment>File size: gigabytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3065"/>
        <source>TB</source>
        <extracomment>File size: terabytes</extracomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3158"/>
        <source>Page size:</source>
        <translation>쪽 크기:</translation>
    </message>
    <message>
        <location filename="../src/PDFDocumentView.cpp" line="3159"/>
        <source>File size:</source>
        <translation>파일 크기:</translation>
    </message>
</context>
</TS>
